@@ -1,7 +1,6 @@
 """
 *common tools used throughout package*
 """
-# from .set_of_files import set_of_files
 from .keyword_lookup import keyword_lookup
 from .detector_lookup import detector_lookup
 from .create_dispersion_map import create_dispersion_map
@@ -13,5 +12,13 @@ from . import toolkit
 from .detect_order_edges import detect_order_edges
 from .filenamer import filenamer
 from .dispersion_map_to_pixel_arrays import dispersion_map_to_pixel_arrays
+from .dispersion_map_to_pixel_arrays import get_cached_coeffs
 from .subtract_background import subtract_background
 from .subtract_sky import subtract_sky
+from .data_organiser import data_organiser
+from .uncompress import uncompress
+from .horne_extraction import horne_extraction
+from .response_function import response_function
+from .flux_calibration import flux_calibration
+from .reducer import reducer
+# from .set_of_files import set_of_files
