@@ -16,6 +16,7 @@ import sys
 import os
 
 
+
 os.environ['TERM'] = 'vt100'
 
 
@@ -98,7 +99,8 @@ class horne_extraction(object):
         from soxspipe.commonutils import detect_continuum
         from soxspipe.commonutils.toolkit import unpack_order_table
         from soxspipe.commonutils import detector_lookup
-        from ccdproc import cosmicray_lacosmic
+        from ccdproc import cosmicray_lacosmic, cosmicray_median
+        from matplotlib import pyplot as plt
 
         self.log = log
         log.debug("instantiating a new 'horne_extraction' object")
@@ -141,9 +143,13 @@ class horne_extraction(object):
         if True and self.recipeSettings["use_lacosmic"]:
             oldCount = self.skySubtractedFrame.mask.sum()
             oldMask = self.skySubtractedFrame.mask.copy()
-            self.skySubtractedFrame = cosmicray_lacosmic(self.skySubtractedFrame, sigclip=4.0, gain_apply=False, niter=5, cleantype="meanmask")
+            self.skySubtractedFrame = cosmicray_lacosmic(self.skySubtractedFrame, sigclip=18.0, gain_apply=False, niter=5, cleantype="meanmask", objlim=5.0,invar=self.skySubtractedFrame.uncertainty.array.astype("float32"),verbose=False)
             newCount = self.skySubtractedFrame.mask.sum()
-            self.skySubtractedFrame.mask = oldMask
+            self.laCosmicClippedCount = newCount - oldCount
+            # self.skySubtractedFrame.mask = oldMask
+            from soxspipe.commonutils.toolkit import quicklook_image
+            quicklook_image(log=self.log, CCDObject=self.skySubtractedFrame, show=False, ext='mask', stdWindow=3, title=False, surfacePlot=False, dispMap=dispersionMap, dispMapImage=twoDMapPath, settings=self.settings, skylines=False)
+
 
         # CHECK SKY MODEL FRAME IS USED (ONLY IN STARE MODE)
         if skyModelFrame == False:
@@ -647,6 +653,7 @@ class horne_extraction(object):
         from astropy.nddata import VarianceUncertainty
         from specutils.manipulation import median_smooth
         from astropy.stats import sigma_clipped_stats
+        from scipy.interpolate import interp1d
 
         # ASTROPY HAS RESET LOGGING LEVEL -- FIX
         import logging
@@ -735,13 +742,13 @@ class horne_extraction(object):
         # DEFINE THE WAVELENGTH ARRAY
         wave_resample_grid = np.arange(float(format(np.min(extractedOrdersDF['wavelengthMedian']) * ratio, '.0f')) / ratio, float(format(np.max(extractedOrdersDF['wavelengthMedian']) * ratio, '.0f')) / ratio, step=stepWavelengthOrderMerge)
         wave_resample_grid = wave_resample_grid * u.nm
+        # SAVE THE COUNTS BY DIVING FOR THE PROPER PIXEL SIZE IN WAVELENGTH SPACE - COUNTS ARE THEN E-/NM
 
-        # INTERPOLATE THE ORDER SPECTRUM INTO THIS NEW ARRAY WITH A SINGLE STEP SIZE
-        if "PAE" in self.settings and self.settings["PAE"] and True:
-            flux_orig = extractedOrdersDF['extractedFluxBoxcarRobust'].values * u.electron
-        else:
-            flux_orig = extractedOrdersDF['extractedFluxOptimal'].values * u.electron
-        # PASS ORIGINAL RAW SPECTRUM AND RESAMPLE
+        extractedOrdersDF['extractedFluxOptimal'] = extractedOrdersDF['extractedFluxOptimal'].values / extractedOrdersDF['pixelScaleNm'].values
+        extractedOrdersDF['extractedFluxBoxcar'] = extractedOrdersDF['extractedFluxBoxcar'].values / extractedOrdersDF['pixelScaleNm'].values
+        extractedOrdersDF['extractedFluxBoxcarRobust'] = extractedOrdersDF['extractedFluxBoxcarRobust'].values / extractedOrdersDF['pixelScaleNm'].values
+
+        flux_orig = extractedOrdersDF['extractedFluxOptimal'].values * u.electron
         spectrum_orig = Spectrum1D(flux=flux_orig, spectral_axis=extractedOrdersDF['wavelengthMedian'].values * u.nm, uncertainty=VarianceUncertainty(extractedOrdersDF["varianceSpectrum"].values))
 
         resampler = FluxConservingResampler()
@@ -751,6 +758,14 @@ class horne_extraction(object):
         merged_orders['WAVE'] = flux_resampled.spectral_axis
         merged_orders['FLUX_COUNTS'] = flux_resampled.flux
 
+        if False:
+            # PLOTTING THE RESAMPLED AND ORIGINAL SPECTRUM
+            import matplotlib.pyplot as plt
+            plt.plot(extractedOrdersDF['wavelengthMedian'], extractedOrdersDF['extractedFluxOptimal'].values, label='Original')
+            plt.plot(merged_orders['WAVE'], merged_orders['FLUX_COUNTS'], label='Resampled')
+            plt.legend()
+            plt.show()
+
         self.plot_merged_spectrum_qc(merged_orders)
 
         return merged_orders
