@@ -1,7 +1,7 @@
 """
 *The pipeline recipes*
 """
-from ._base_recipe_ import _base_recipe_
+from .base_recipe import base_recipe
 from .soxs_mbias import soxs_mbias
 from .soxs_mdark import soxs_mdark
 from .soxs_disp_solution import soxs_disp_solution
@@ -9,4 +9,5 @@ from .soxs_order_centres import soxs_order_centres
 from .soxs_mflat import soxs_mflat
 from .soxs_spatial_solution import soxs_spatial_solution
 from .soxs_straighten import soxs_straighten
-from .soxs_nod_mode import soxs_nod_mode
+from .soxs_stare import soxs_stare
+from .soxs_nod import soxs_nod
