@@ -3,19 +3,18 @@
 """
 *The recipe for creating master-bias frames *
 
-:Author:
-    David Young & Marco Landoni
+Author
+: David Young & Marco Landoni
 
-:Date Created:
-    January 22, 2020
+Date Created
+: January 22, 2020
 """
 ################# GLOBAL IMPORTS ####################
 
 from soxspipe.commonutils.toolkit import generic_quality_checks
 from datetime import datetime
 from soxspipe.commonutils import keyword_lookup
-import math
-from ._base_recipe_ import _base_recipe_
+from .base_recipe import base_recipe
 from fundamentals import tools
 from builtins import object
 import sys
@@ -25,9 +24,9 @@ import os
 os.environ['TERM'] = 'vt100'
 
 
-class soxs_mbias(_base_recipe_):
+class soxs_mbias(base_recipe):
     """
-    *The* `soxs_mbias` *recipe is used to generate a master-bias frame from a set of input raw bias frames. The recipe is used only for the UV-VIS arm as NIR frames have bias (and dark current) removed by subtracting an off-frame of equal expsoure length.*
+    *The* `soxs_mbias` *recipe is used to generate a master-bias frame from a set of input raw bias frames. The recipe is used only for the UV-VIS arm as NIR frames have bias (and dark current) removed by subtracting an off-frame of equal exposure length.*
 
     **Key Arguments**
 
@@ -35,7 +34,9 @@ class soxs_mbias(_base_recipe_):
     - ``settings`` -- the settings dictionary
     - ``inputFrames`` -- input fits frames. Can be a directory, a set-of-files (SOF) file or a list of fits frame paths.
     - ``verbose`` -- verbose. True or False. Default *False*
-    - ``overwrite`` -- overwrite the prodcut file if it already exists. Default *False*
+    - ``overwrite`` -- overwrite the product file if it already exists. Default *False*
+    - ``command`` -- the command called to run the recipe
+
 
     **Usage**
 
@@ -47,13 +48,6 @@ class soxs_mbias(_base_recipe_):
         inputFrames=fileList
     ).produce_product()
     ```
-
-    ---
-
-    ```eval_rst
-    .. todo::
-        - add a tutorial about ``soxs_mbias`` to documentation
-    ```
     """
     # Initialisation
 
@@ -63,17 +57,15 @@ class soxs_mbias(_base_recipe_):
             settings=False,
             inputFrames=[],
             verbose=False,
-            overwrite=False
+            overwrite=False,
+            command=False
     ):
-        # INHERIT INITIALISATION FROM  _base_recipe_
-        super(soxs_mbias, self).__init__(log=log, settings=settings, inputFrames=inputFrames, overwrite=overwrite, recipeName="soxs-mbias")
-        self.log = log
-        log.debug("instansiating a new 'soxs_mbias' object")
+        # INHERIT INITIALISATION FROM  base_recipe
+        this = super(soxs_mbias, self).__init__(log=log, settings=settings, inputFrames=inputFrames, overwrite=overwrite, recipeName="soxs-mbias", command=command)
+        log.debug("instantiating a new 'soxs_mbias' object")
         self.settings = settings
         self.inputFrames = inputFrames
         self.verbose = verbose
-        self.recipeSettings = settings[self.recipeName]
-        # xt-self-arg-tmpx
 
         # INITIAL ACTIONS
         # CONVERT INPUT FILES TO A CCDPROC IMAGE COLLECTION (inputFrames >
@@ -89,15 +81,14 @@ class soxs_mbias(_base_recipe_):
 
         # VERIFY THE FRAMES ARE THE ONES EXPECTED BY SOXS_MBIAS - NO MORE, NO LESS.
         # PRINT SUMMARY OF FILES.
-        print("# VERIFYING INPUT FRAMES")
+        self.log.print("# VERIFYING INPUT FRAMES")
         self.verify_input_frames()
+        sys.stdout.flush()
         sys.stdout.write("\x1b[1A\x1b[2K")
-        print("# VERIFYING INPUT FRAMES - ALL GOOD")
+        self.log.print("# VERIFYING INPUT FRAMES - ALL GOOD")
 
-        # print("\n# RAW INPUT BIAS FRAMES - SUMMARY")
         # SORT IMAGE COLLECTION
         self.inputFrames.sort(['MJD-OBS'])
-        # print(self.inputFrames.summary, "\n")
 
         # PREPARE THE FRAMES - CONVERT TO ELECTRONS, ADD UNCERTAINTY AND MASK
         # EXTENSIONS
@@ -110,7 +101,7 @@ class soxs_mbias(_base_recipe_):
             self):
         """*verify the input frame match those required by the soxs_mbias recipe*
 
-        If the fits files conform to required input for the recipe everything will pass silently, otherwise an exception shall be raised.
+        If the fits files conform to the required input for the recipe, everything will pass silently; otherwise, an exception will be raised.
         """
         self.log.debug('starting the ``verify_input_frames`` method')
 
@@ -119,17 +110,22 @@ class soxs_mbias(_base_recipe_):
         # BASIC VERIFICATION COMMON TO ALL RECIPES
         imageTypes, imageTech, imageCat = self._verify_input_frames_basics()
 
+        error = False
+
         # MIXED INPUT IMAGE TYPES ARE BAD
         if len(imageTypes) > 1:
-            imageTypes = " and ".join(imageTypes)
-            print(self.inputFrames.summary)
-            raise TypeError(
-                "Input frames are a mix of %(imageTypes)s" % locals())
+            error = "Input frames are a mix of %(imageTypes)s" % locals()
         # NON-BIAS INPUT IMAGE TYPES ARE BAD
         elif imageTypes[0] != 'BIAS':
-            print(self.inputFrames.summary)
-            raise TypeError(
-                "Input frames not BIAS frames" % locals())
+            error = "Input frames not BIAS frames" % locals()
+
+        if error:
+            sys.stdout.flush()
+            sys.stdout.write("\x1b[1A\x1b[2K")
+            self.log.error("# VERIFYING INPUT FRAMES - **ERROR**\n")
+            self.log.print(self.inputFrames.summary)
+            self.log.print("")
+            raise TypeError(error)
 
         self.imageType = imageTypes[0]
 
@@ -141,11 +137,13 @@ class soxs_mbias(_base_recipe_):
         """*generate a master bias frame*
 
         **Return:**
-            - ``productPath`` -- the path to the master bias frame
+
+        - ``productPath`` -- the path to the master bias frame
         """
         self.log.debug('starting the ``produce_product`` method')
 
         import numpy as np
+        import pandas as pd
 
         arm = self.arm
         kw = self.kw
@@ -154,7 +152,7 @@ class soxs_mbias(_base_recipe_):
         # LIST OF CCDDATA OBJECTS
         ccds = [c for c in self.inputFrames.ccds(ccd_kwargs={"hdu_uncertainty": 'ERRS', "hdu_mask": 'QUAL', "hdu_flags": 'FLAGS', "key_uncertainty_type": 'UTYPE'})]
 
-        meanBiasLevels, rons, noiseFrames = zip(*[self.subtact_mean_flux_level(c) for c in ccds])
+        meanBiasLevels, rons, noiseFrames = zip(*[self.subtract_mean_flux_level(c) for c in ccds])
         masterMeanBiasLevel = np.mean(meanBiasLevels)
         masterMedianBiasLevel = np.median(meanBiasLevels)
         rawRon = np.mean(rons)
@@ -164,17 +162,11 @@ class soxs_mbias(_base_recipe_):
 
         masterRon = np.std(combined_noise.data)
 
-        # FILL MASKED PIXELS WITH 0
+        # USE COMBINED NOISE MASK AS MBIAS MASK
         combined_noise.data = np.ma.array(combined_noise.data, mask=combined_noise.mask, fill_value=0).filled() + masterMeanBiasLevel
         combined_noise.uncertainty = np.ma.array(combined_noise.uncertainty.array, mask=combined_noise.mask, fill_value=rawRon).filled()
         combined_bias_mean = combined_noise
-        combined_bias_mean.mask[:] = False
-
-        # # MULTIPROCESSING HERE ADDS A SELF_DEFEATING OVERHEAD
-        # from fundamentals import fmultiprocess
-        # # DEFINE AN INPUT ARRAY
-        # results = fmultiprocess(log=self.log, function=self.subtact_mean_flux_level,
-        #                         inputArray=ccds, poolSize=False, timeout=300)
+        combined_bias_mean.mask = combined_noise.mask
 
         self.qc_periodic_pattern_noise(frames=self.inputFrames)
 
@@ -206,7 +198,7 @@ class soxs_mbias(_base_recipe_):
         # WRITE TO DISK
         productPath = self._write(
             frame=combined_bias_mean,
-            filedir=self.intermediateRootPath,
+            filedir=self.workspaceRootPath,
             filename=False,
             overwrite=True
         )
@@ -217,7 +209,7 @@ class soxs_mbias(_base_recipe_):
 
         self.dateObs = combined_bias_mean.header[self.kw("DATE_OBS")]
 
-        self.products = self.products.append({
+        self.products = pd.concat([self.products, pd.Series({
             "soxspipe_recipe": self.recipeName,
             "product_label": "MBIAS",
             "file_name": filename,
@@ -225,8 +217,9 @@ class soxs_mbias(_base_recipe_):
             "obs_date_utc": self.dateObs,
             "reduction_date_utc": utcnow,
             "product_desc": f"{self.arm} Master bias frame",
-            "file_path": productPath
-        }, ignore_index=True)
+            "file_path": productPath,
+            "label": "PROD"
+        }).to_frame().T], ignore_index=True)
 
         self.report_output()
         self.clean_up()
@@ -240,11 +233,13 @@ class soxs_mbias(_base_recipe_):
         """*calculate the structure of the bias*
 
         **Key Arguments:**
-            - ``combined_bias_mean`` -- the mbias frame
+
+        - ``combined_bias_mean`` -- the mbias frame
 
         **Return:**
-            - ``structx`` -- slope of BIAS in X direction
-            - ``structx`` -- slope of BIAS in Y direction
+
+        - ``structx`` -- slope of BIAS in X direction
+        - ``structx`` -- slope of BIAS in Y direction
 
         **Usage:**
 
@@ -255,6 +250,7 @@ class soxs_mbias(_base_recipe_):
         self.log.debug('starting the ``qc_bias_structure`` method')
 
         import numpy as np
+        import pandas as pd
         plot = False
 
         collaps_ax1 = np.nansum(combined_bias_mean, axis=0)
@@ -284,7 +280,7 @@ class soxs_mbias(_base_recipe_):
         utcnow = datetime.utcnow()
         utcnow = utcnow.strftime("%Y-%m-%dT%H:%M:%S")
 
-        self.qc = self.qc.append({
+        self.qc = pd.concat([self.qc, pd.Series({
             "soxspipe_recipe": self.recipeName,
             "qc_name": "STRUCTX",
             "qc_value": coeff_ax1[0],
@@ -293,9 +289,9 @@ class soxs_mbias(_base_recipe_):
             "obs_date_utc": self.dateObs,
             "reduction_date_utc": utcnow,
             "to_header": True
-        }, ignore_index=True)
+        }).to_frame().T], ignore_index=True)
 
-        self.qc = self.qc.append({
+        self.qc = pd.concat([self.qc, pd.Series({
             "soxspipe_recipe": self.recipeName,
             "qc_name": "STRUCTY",
             "qc_value": coeff_ax2[0],
@@ -304,7 +300,7 @@ class soxs_mbias(_base_recipe_):
             "obs_date_utc": self.dateObs,
             "reduction_date_utc": utcnow,
             "to_header": True
-        }, ignore_index=True)
+        }).to_frame().T], ignore_index=True)
 
         self.log.debug('completed the ``qc_bias_structure`` method')
         return coeff_ax1[0], coeff_ax2[0]
@@ -317,10 +313,12 @@ class soxs_mbias(_base_recipe_):
         A 2D FFT is applied to each of the raw bias frames and the standard deviation and median absolute deviation calcualted for each result. The maximum std/mad is then added as the ppnmax QC in the master bias frame header.
 
         **Key Arguments:**
-            - ``frames`` -- the raw bias frames (imageFileCollection)
+
+        - ``frames`` -- the raw bias frames (imageFileCollection)
 
         **Return:**
-            - ``ppnmax``
+
+        - ``ppnmax``
 
         **Usage:**
 
@@ -333,6 +331,8 @@ class soxs_mbias(_base_recipe_):
         from scipy.stats import median_abs_deviation
         from astropy.stats import sigma_clip
         import numpy as np
+        import pandas as pd
+        from ccdproc import block_reduce
 
         # LIST OF CCDDATA OBJECTS
         ccds = [c for c in frames.ccds(ccd_kwargs={"hdu_uncertainty": 'ERRS', "hdu_mask": 'QUAL', "hdu_flags": 'FLAGS', "key_uncertainty_type": 'UTYPE'})]
@@ -341,16 +341,18 @@ class soxs_mbias(_base_recipe_):
         for frame in ccds:
             # FORCE CONVERSION OF CCDData OBJECT TO NUMPY ARRAY
             maskedDataArray = np.ma.array(frame.data, mask=frame.mask)
+            # BIN THE FRAME TO INCREASE SPEED
+            maskedDataArray = block_reduce(maskedDataArray, 5, np.mean)
             dark_image_grey_fourier = np.fft.fftshift(np.fft.fft2(maskedDataArray.filled(np.median(frame.data))))
 
             # SIGMA-CLIP THE DATA
             masked_dark_image_grey_fourier = sigma_clip(
-                dark_image_grey_fourier, sigma_lower=1000, sigma_upper=1000, maxiters=1, cenfunc='mean')
+                dark_image_grey_fourier, sigma_lower=100, sigma_upper=100, maxiters=1, cenfunc='mean')
             goodData = np.ma.compressed(masked_dark_image_grey_fourier)
 
             # frame_mad = median_abs_deviation(dark_image_grey_fourier, axis=None)
             # frame_std = np.std(dark_image_grey_fourier)
-            # print(frame_std, frame_mad, frame_std / frame_mad)
+            # self.log.print(frame_std, frame_mad, frame_std / frame_mad)
 
             frame_mad = median_abs_deviation(goodData, axis=None)
             frame_std = np.std(goodData)
@@ -358,6 +360,8 @@ class soxs_mbias(_base_recipe_):
             from soxspipe.commonutils.toolkit import quicklook_image
             quicklook_image(
                 log=self.log, CCDObject=abs(masked_dark_image_grey_fourier), show=False, ext=None, stdWindow=0.1)
+            quicklook_image(
+                log=self.log, CCDObject=abs(dark_image_grey_fourier), show=False, ext=None, stdWindow=0.1)
 
             ratios.append(frame_std / frame_mad)
 
@@ -366,7 +370,7 @@ class soxs_mbias(_base_recipe_):
 
         ppnmax = max(ratios)
 
-        self.qc = self.qc.append({
+        self.qc = pd.concat([self.qc, pd.Series({
             "soxspipe_recipe": self.recipeName,
             "qc_name": "PPNMAX",
             "qc_value": ppnmax,
@@ -375,7 +379,7 @@ class soxs_mbias(_base_recipe_):
             "obs_date_utc": self.dateObs,
             "reduction_date_utc": utcnow,
             "to_header": True
-        }, ignore_index=True)
+        }).to_frame().T], ignore_index=True)
 
         self.log.debug('completed the ``qc_periodic_pattern_noise`` method')
         return ppnmax
